add_signoff = 'add_signoff'
amend = 'amend'
amend_mode = 'amend_mode'
apply_diff_selection = 'apply_diff_selection'
apply_patches = 'apply_patches'
branch_mode = 'branch_mode'
commit = 'commit'
edit = 'edit'
checkout = 'checkout'
checkout_branch = 'checkout_branch'
cherry_pick = 'cherry_pick'
clone = 'clone'
delete = 'delete'
delete_branch = 'delete_branch'
diff = 'diff'
diff_expr_mode = 'diff_expr_mode'
diff_mode = 'diff_mode'
diff_staged = 'diff_staged'
diff_text = 'diff_text'
diffstat = 'diffstat'
difftool = 'difftool'
editor_text = 'editor_text'
format_patch = 'format_patch'
grep = 'grep'
information = 'information'
inotify = 'inotify'
log_cmd = 'log_cmd'
load_commit_message = 'load_commit_message'
load_commit_template = 'load_commit_template'
mergetool = 'mergetool'
mode = 'mode'
modified_summary = 'modified_summary'
open_repo = 'open_repo'
question = 'question'
redo = 'redo'
rescan = 'rescan'
reset_mode = 'reset_mode'
review_branch_mode = 'review_branch_mode'
run_config_action = 'run_config_action'
run_command = 'run_command'
show_untracked = 'show_untracked'
stage = 'stage'
stage_diffs = 'stage_diffs'
stage_modified = 'stage_modified'
stage_untracked = 'stage_untracked'
staged_summary = 'staged_summary'
tag = 'tag'
unmerged_summary = 'unmerged_summary'
undo = 'undo'
undo_diffs = 'undo_diffs'
unstage = 'unstage'
unstage_diffs = 'unstage_diffs'
unstage_all = 'unstage_all'
unstage_selected = 'unstage_selected'
untracked_summary = 'untracked_summary'
visualize_all = 'visualize_all'
visualize_current = 'visualize_current'
visualize_paths = 'visualize_paths'
